@@ -142,7 +142,7 @@ where\n\
     -sv                 enables save-on-exit\n\
     -ns                 disables the auto save feature\n\
     -na                 disables the alarm feature\n\
-    -help | -?          prints this help message\n\
+    -help | -? | -h     prints this help message\n\
     -bs bufsize         sets the buffer size for all notes\n\
     -dir notedir        specifies the directory to load and save notes\n\
     -interval minutes   specifies the auto-save timeout value\n\
@@ -153,7 +153,7 @@ where\n\
     -calendarcmd cmd    calendar command\n\
     -emailcmd cmd       command to use to send email\n\
     -homedir path       default home directory (used by file selection window\n\
-    -version            print the current version number\n\
+    -version | -V       print the current version number\n\
 \n\
 "
 
